Documentation
¶
Overview ¶
----------------------------------------------------------------------------- Copyright (c) 2024-2025 Sven C. Zeisberg, Zeisberg GmbH, Germany. All rights reserved. Description: merlinshell is a simple interactive shell for the Merlin board.
It provides a command line interface to control the Merlin board interactively via the MerlinHAL interface.
-----------------------------------------------------------------------------
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MerlinShellType ¶
type MerlinShellType struct {
// contains filtered or unexported fields
}
func NewMerlinShell ¶
func NewMerlinShell(h *boardctrl.MerlinHAL) *MerlinShellType
NewMerlinShell creates a new MerlinShell object
func (*MerlinShellType) AddLogOnOffCommand ¶
func (ms *MerlinShellType) AddLogOnOffCommand()
func (*MerlinShellType) AddLogfileCommand ¶
func (ms *MerlinShellType) AddLogfileCommand()
func (*MerlinShellType) AddsetfixledCommand ¶
func (ms *MerlinShellType) AddsetfixledCommand()
func (*MerlinShellType) Run ¶
func (ms *MerlinShellType) Run()
Click to show internal directories.
Click to hide internal directories.